@@ -14,7 +14,9 @@
 
 int debug_flag = 0; /* per default no debug messages */
 
-void 
+FILE *debug_output = NULL;
+
+void
 log_msg (char *fmt,...)
 {
   va_list ap;
@@ -22,11 +24,15 @@ log_msg (char *fmt,...)
   char msg[512];
 #endif
 
+  if (debug_output == NULL)
+    debug_output = stderr;
+
   va_start (ap, fmt);
   if (debug_flag)
     {
-      vfprintf (stderr, fmt, ap);
-      fputc ('\n', stderr);
+      vfprintf (debug_output, fmt, ap);
+      fputc ('\n', debug_output);
+      fflush (debug_output);
     }
   else
     {
