@@ -29,9 +29,12 @@
 #include <unistd.h>
 #include <rpc/types.h>
 #include <rpcsvc/ypclnt.h>
+#ifdef HAVE_GETOPT_H
 #include <getopt.h>
+#endif
 
 #include "mknetid.h"
+#include "compat.h"
 
 static int quiet_flag = 0;
 
@@ -156,10 +159,10 @@ main (int argc, char *argv[])
 
   while (!feof (file))
     {
-#ifdef HAVE_GETLINE
-      ssize_t n = getline (&line, &length, file);
-#elif HAVE_GETDELIM
+#if HAVE_GETDELIM
       ssize_t n = getdelim (&line, &length, '\n', file);
+#else
+      ssize_t n = getline (&line, &length, file);
 #endif
       if (n < 1)
 	break;
@@ -189,10 +192,10 @@ main (int argc, char *argv[])
 
   while (!feof (file))
     {
-#ifdef HAVE_GETLINE
-      ssize_t n = getline (&line, &length, file);
-#elif HAVE_GETDELIM
+#if HAVE_GETDELIM
       ssize_t n = getdelim (&line, &length, '\n', file);
+#else
+      ssize_t n = getline (&line, &length, file);
 #endif
       if (n < 1)
 	break;
@@ -224,10 +227,10 @@ main (int argc, char *argv[])
 
   while (!feof (file))
     {
-#ifdef HAVE_GETLINE
-      ssize_t n = getline (&line, &length, file);
-#elif HAVE_GETDELIM
+#if HAVE_GETDELIM
       ssize_t n = getdelim (&line, &length, '\n', file);
+#else
+      ssize_t n = getline (&line, &length, file);
 #endif
       if (n < 1)
 	break;
@@ -260,10 +263,10 @@ main (int argc, char *argv[])
     {
       while (!feof (file))
 	{
-#ifdef HAVE_GETLINE
-	  ssize_t n = getline (&line, &length, file);
-#elif HAVE_GETDELIM
+#if HAVE_GETDELIM
 	  ssize_t n = getdelim (&line, &length, '\n', file);
+#else
+	  ssize_t n = getline (&line, &length, file);
 #endif
 	  if (n < 1)
 	    break;
